@@ -5,7 +5,6 @@ import ubjson
 from multiprocessing.dummy import Pool
 
 
-
 class GSCNodeFunctionReceiverSocket:
     @classmethod
     def create(cls, sio, gsdbs, oncnodefunction, poolsize):
@@ -23,7 +22,6 @@ class GSCNodeFunctionReceiverSocket:
 
         def on_success(r):
             pass
-            # self._logger.info('cnodefunction succeed')
 
         def on_errorPost(error):
             self._logger.exception('cnodefunction failed :' + error)
@@ -111,7 +109,7 @@ class GSCNodeFunctionCaller:
                                            self.oncnodefunctionanswer)
 
     def on_success(self, r):
-        self._logger.info('cnodefunction succeed')
+        self._logger.debug('cnodefunction succeed')
 
     def on_errorPost(self, error):
         self._logger.exception('cnodefunction failed :' + error)
